@@ -35,9 +35,7 @@ except ImportError:  # pragma: no cover
     pass
 
 
-__all__ = (
-    "CachingMostRecentProvider",
-)
+__all__ = ("CachingMostRecentProvider",)
 _LOGGER = logging.getLogger(LOGGER_NAME)
 #: Grace period during which we will return the latest local materials. This allows multiple
 #: threads to be using this same provider without risking lock contention or many threads
@@ -282,7 +280,7 @@ class CachingMostRecentProvider(CryptographicMaterialsProvider):
         :raises AttributeError: if provider could not locate version
         """
         blocking_wait = bool(ttl_action is TtlActions.EXPIRED)
-        acquired = self._lock.acquire(blocking_wait)
+        acquired = self._lock.acquire(blocking_wait)  # pylint: disable=consider-using-with
         if not acquired:
             # We failed to acquire the lock.
             # If blocking, we will never reach this point.
@@ -320,7 +318,7 @@ class CachingMostRecentProvider(CryptographicMaterialsProvider):
         :rtype: CryptographicMaterialsProvider
         """
         blocking_wait = bool(ttl_action is TtlActions.EXPIRED)
-        acquired = self._lock.acquire(blocking_wait)
+        acquired = self._lock.acquire(blocking_wait)  # pylint: disable=consider-using-with
 
         if not acquired:
             # We failed to acquire the lock.
